import {Component, EventEmitter, inject, Input, OnInit, Output} from '@angular/core';
import {
  AbstractControl,
  FormControl,
  FormGroup,
  FormsModule,
  ReactiveFormsModule,
  ValidationErrors, Validators
} from "@angular/forms";
import {Hotel} from "./hotel";
import {HotelService} from "../service/hotel.service";
import {RouterLink} from "@angular/router";
import {HotelsComponent} from "./hotels.component";

@Component({
  selector: 'app-create-hotel',
  standalone: true,
  imports: [
    FormsModule,
    ReactiveFormsModule,
    RouterLink
  ],
  template: `
    <ng-form [formGroup]="form" (ngSubmit)="submit()">
      <label for="name">Name</label>
      <br>
      <input id="name" type="text" formControlName="name">
      <br>
      <label for="description">Description</label>
      <br>
      <input id="description" type="text" formControlName="description">
      <br>
      <label for="price">Price</label>
      <br>
      <input id="price" type="number" formControlName="price">
      <br>
      <label for="rating">Rating</label>
      <br>
      <input id="rating" type="number" formControlName="rating" min="0" max="5">
      <br>
      <br>
      <button type="submit" (click)="submit()">Submit</button>
    </ng-form>

    <button routerLink="/hotels">back</button>
  `,
})
export class EditHotelComponent implements OnInit {
  @Input()
  hotel: Hotel | null = null;

  @Output()
  updateHotel: EventEmitter<Hotel> = new EventEmitter

  form!: FormGroup

  ngOnInit(): void {
    this.form = new FormGroup({
      name: new FormControl(this.hotel?.hotelName, [Validators.required]),
      description: new FormControl(this.hotel?.description, [Validators.required]),
      price: new FormControl(this.hotel?.price, [Validators.required]),
      rating: new FormControl(this.hotel?.rating, [Validators.required, Validators.min(0), Validators.max(5)]),
    })
  }

  submit() {
    if (!this.form.valid) {
      console.error('Form invalid');

      return;
    }

    const hotel: Hotel = {
      imageUrl: this.hotel?.imageUrl ?? "",
      hotelName: this.form.value.name,
      description: this.form.value.description,
      price: this.form.value.price,
      rating: this.form.value.rating,
      id: this.hotel?.id ?? 0,
    };

    this.updateHotel.emit(hotel)

    this.hotel = hotel;
  }
}
